@@ -12,7 +12,7 @@ Base.@kwdef @concrete struct GridSample <: DeterministicSamplingAlgorithm
 end
 
 function sample(n::Integer, d::Integer, S::GridSample, T = Float64)
-    samples = rand.(range.(zeros(T, d), ones(T,d); length = n+1), Ref(n))
+    samples = rand.(range.(zeros(T, d), ones(T, d); length = n + 1), Ref(n))
     randomize(mapreduce(permutedims, vcat, samples), S.R)
 end
 
@@ -27,5 +27,6 @@ end
 
 function sample(n::Integer, d::Integer, S::LatticeRuleSample, T = Float64)
     lat = LatticeRules.LatticeRule(d)
-    return randomize(reduce(hcat, lat[0:(n - 1)]), S.R)
+    result = reduce(hcat, lat[0:(n - 1)])
+    return randomize(T == Float64 ? result : T.(result), S.R)
 end
