@@ -52,11 +52,11 @@ Return a QMC point set where:
   - `lb` is the lower bound for each variable. Its length fixes the dimensionality of the sample.
   - `ub` is the upper bound. Its dimension must match `length(lb)`.
 
-In the first method the type of the point set is specified by `T` while in the second method the output type is infered from the bound types.
+In the first method the type of the point set is specified by `T` while in the second method the output type is inferred from the bound types.
 """
 function sample(n::Integer, lb::T, ub::T,
-    S::D) where {T <: Union{Base.AbstractVecOrTuple, Number},
-    D <: SamplingAlgorithm}
+        S::D) where {T <: Union{Base.AbstractVecOrTuple, Number},
+        D <: SamplingAlgorithm}
     _check_sequence(lb, ub, n)
     lb = float.(lb)
     ub = float.(ub)
@@ -78,6 +78,7 @@ include("Kronecker.jl")
 include("Halton.jl")
 include("Sobol.jl")
 include("LatinHypercube.jl")
+include("RandomizedHalton.jl")
 include("Lattices.jl")
 include("Section.jl")
 
@@ -95,34 +96,27 @@ include("RandomizedQuasiMonteCarlo/shifting.jl")
 include("RandomizedQuasiMonteCarlo/scrambling_base_b.jl")
 include("RandomizedQuasiMonteCarlo/iterators.jl")
 
-import Requires
-@static if !isdefined(Base, :get_extension)
-    function __init__()
-        Requires.@require Distributions="31c24e10-a181-5473-b8eb-7969acd0382f" begin
-            include("../ext/QuasiMonteCarloDistributionsExt.jl")
-        end
-    end
-end
+include("precompile.jl")
 
 export SamplingAlgorithm,
-    GridSample,
-    SobolSample,
-    LatinHypercubeSample,
-    LatticeRuleSample,
-    RandomSample,
-    HaltonSample,
-    VanDerCorputSample,
-    GoldenSample,
-    KroneckerSample,
-    SectionSample,
-    FaureSample,
-    randomize,
-    RandomizationMethod,
-    NoRand,
-    Shift,
-    ScrambleMethod,
-    OwenScramble,
-    MatousekScramble,
-    DigitalShift,
-    DesignMatrix
+       GridSample,
+       SobolSample,
+       LatinHypercubeSample,
+       RandomizedHaltonSample,
+       LatticeRuleSample,
+       RandomSample,
+       HaltonSample,
+       VanDerCorputSample,
+       GoldenSample,
+       KroneckerSample,
+       FaureSample,
+       randomize,
+       RandomizationMethod,
+       NoRand,
+       Shift,
+       ScrambleMethod,
+       OwenScramble,
+       MatousekScramble,
+       DigitalShift,
+       DesignMatrix
 end # module
