@@ -1,10 +1,9 @@
 using QuasiMonteCarlo
-using Aqua, Test
-# Aqua.test_all(QuasiMonteCarlo)
+using Test
+include("qa.jl")
 
-using Compat
 using Statistics, LinearAlgebra, StatsBase, Random
-using Primes, Combinatorics, Distributions, InvertedIndices, IntervalArithmetic
+using Primes, Combinatorics, Distributions, IntervalArithmetic
 using HypothesisTests
 
 # struct InertSampler <: Random.AbstractRNG end
@@ -44,7 +43,7 @@ The test is exact if the element of `net` are of type `Rational`. Indeed, in tha
 The conversion `Float` to `Rational` is usually possible with usual nets, e.g., Sobol, Faure (may require `Rational{BigInt}.(net)`).
 """
 function istmsnet(net::AbstractMatrix{T}; λ::I, t::I, m::I, s::I,
-    base::I) where {I <: Integer, T <: Real}
+        base::I) where {I <: Integer, T <: Real}
     pass = true
 
     @assert size(net, 2)==λ * (base^m) "Number of points must be as size(net, 2) = $(size(net, 2)) == λ * (base^m) = $(λ * (base^m))"
@@ -93,7 +92,7 @@ for point_constructor in [
     LatinHypercubeSample(),
     LatticeRuleSample(),
     RandomSample(),
-    SobolSample(),
+    SobolSample()
 ]
     @show point_constructor
     s = QuasiMonteCarlo.sample(n, lb, ub, point_constructor)
@@ -146,7 +145,7 @@ end
     s = sortslices(s; dims = 2)
     differences = diff(s; dims = 2)
     # test for grid
-    @test all(x -> all(y -> y in 0.0:1/n:1.0, x), eachrow(s))
+    @test all(x -> all(y -> y in 0.0:(1 / n):1.0, x), eachrow(s))
     μ = mean(s; dims = 2)
     variance = var(s; corrected = false, dims = 2)
     for i in eachindex(μ)
@@ -286,37 +285,39 @@ end
     end
 end
 
-@testset "Halton Sequence" begin
+@testset "(Randomized) Halton Sequence" begin
     d = 4
     lb = zeros(d)
     ub = ones(d)
     bases = nextprimes(1, d)
     n = prod(bases)^2
-    s = QuasiMonteCarlo.sample(n, lb, ub, HaltonSample())
-    @test isa(s, Matrix)
-    @test size(s) == (d, n)
-    sorted = reduce(vcat, sort.(eachslice(s; dims = 1))')
-    each_dim = eachrow(sorted)
+    for sample_type in [HaltonSample(), RandomizedHaltonSample()]
+        s = QuasiMonteCarlo.sample(n, lb, ub, sample_type)
+        @test isa(s, Matrix)
+        @test size(s) == (d, n)
+        sorted = reduce(vcat, sort.(eachslice(s; dims = 1))')
+        each_dim = eachrow(sorted)
 
-    # each 1d sequence should have base b stratification property
-    # (property inherited from van der Corput)
-    @test all(zip(each_dim, bases)) do (seq, base)
-        theoretical_count = n ÷ base
-        part = Iterators.partition(seq, theoretical_count)
-        all(enumerate(part)) do (i, subseq)
-            all(subseq) do x
-                i - 1 ≤ base * x ≤ i
+        # each 1d sequence should have base b stratification property
+        # (property inherited from van der Corput)
+        @test all(zip(each_dim, bases)) do (seq, base)
+            theoretical_count = n ÷ base
+            part = Iterators.partition(seq, theoretical_count)
+            all(enumerate(part)) do (i, subseq)
+                all(subseq) do x
+                    i - 1 ≤ base * x ≤ i
+                end
             end
         end
-    end
-    μ = mean(s; dims = 2)
-    variance = var(s; dims = 2)
-    for i in eachindex(μ)
-        @test μ[i]≈0.5 atol=1 / sqrt(n)
-        @test variance[i]≈1 / 12 rtol=1 / sqrt(n)
-    end
-    for (i, j) in combinations(1:d, 2)
-        @test pvalue(SignedRankTest(s[i, :], s[j, :])) > 0.0001
+        μ = mean(s; dims = 2)
+        variance = var(s; dims = 2)
+        for i in eachindex(μ)
+            @test μ[i]≈0.5 atol=1 / sqrt(n)
+            @test variance[i]≈1 / 12 rtol=1 / sqrt(n)
+        end
+        for (i, j) in combinations(1:d, 2)
+            @test pvalue(SignedRankTest(s[i, :], s[j, :])) > 0.0001
+        end
     end
 end
 
@@ -398,7 +399,7 @@ end
         SobolSample(R = OwenScramble(base = 2, pad = m)),
         SobolSample(),
         LatticeRuleSample(R = Shift()),
-        SobolSample(R = MatousekScramble(base = 2, pad = m)),
+        SobolSample(R = MatousekScramble(base = 2, pad = m))
     ]
     for algorithm in algorithms
         Ms = QuasiMonteCarlo.generate_design_matrices(n, lb, ub, algorithm, num_mat)
@@ -426,7 +427,7 @@ end
         # LatticeRuleSample(R = Shift()), # TODO add support for LatticeRule
         SobolSample(R = OwenScramble(base = 2, pad = m)),
         SobolSample(R = MatousekScramble(base = 2, pad = m)),
-        SobolSample(R = DigitalShift(base = 2, pad = m)),
+        SobolSample(R = DigitalShift(base = 2, pad = m))
     ]
     for algorithm in algorithms
         @show algorithm
@@ -435,13 +436,13 @@ end
         @test isa(X, Matrix{eltype(X)}) == true
         μ = [mean(f(c) for c in eachcol(X)) for X in iterator] # Check that iterator do work!
         if !isa(algorithm, Beta) # The Beta distribution is not Uniform hence we do not expect the μ to be close to 1. We could compute the expected results but it would involve a β function dependency.
-            @test μ≈ones(num_mat) atol=5e-2 # the results for different randomization should all be close to 1. Arbitrarily we allow 5% error. 
+            @test μ≈ones(num_mat) atol=5e-2 # the results for different randomization should all be close to 1. Arbitrarily we allow 5% error.
         end
     end
 end
 
 @testset "Types of output and intermediate arrays" begin
-    # Scrambling methods use intermediate array for the bits scrambling. It is in general uncessary to have this large array stored as Int64. 
+    # Scrambling methods use intermediate array for the bits scrambling. It is in general unnecessary to have this large array stored as Int64.
     #TODO test other randomization methods (here just scrambling) and QMC sequence (here just Sobol)
     #TODO here we test output and constructions of intermediate array, we could test that all operation are type stables
     d = 4
@@ -452,10 +453,11 @@ end
         for Int_type in [Int32, Int64]
             b, pad = Int_type(2), Int_type(32)
             scramblings = [OwenScramble(base = b, pad = pad)
-                MatousekScramble(base = b, pad = pad)
-                DigitalShift(base = b, pad = pad)]
+                           MatousekScramble(base = b, pad = pad)
+                           DigitalShift(base = b, pad = pad)]
             for scrambling in scramblings
-                output, other_arrays... = QuasiMonteCarlo.initialize(n,
+                output,
+                other_arrays... = QuasiMonteCarlo.initialize(n,
                     d,
                     SobolSample(),
                     scrambling,
@@ -493,7 +495,7 @@ end
     N = b^m # Number of points
     pad = 2m
 
-    # Unrandomized low discrepency sequence
+    # Unrandomized low discrepancy sequence
     u_faure = QuasiMonteCarlo.sample(N, d, FaureSample())
 
     # Randomized version
@@ -513,7 +515,7 @@ end
     N = b^m # Number of points
     pad = m
 
-    # Unrandomized low discrepency sequence
+    # Unrandomized low discrepancy sequence
     u_sobol = Rational.(QuasiMonteCarlo.sample(N, d, SobolSample()))
     # Randomized version
     u_nus = randomize(u_sobol, OwenScramble(base = b, pad = pad))
@@ -540,7 +542,7 @@ end
         NoRand(),
         OwenScramble(base = base, pad = m),
         MatousekScramble(base = base, pad = m),
-        DigitalShift(base = base, pad = m),
+        DigitalShift(base = base, pad = m)
     ]
     pass = Array{Bool}(undef, length(v), m)
     for (s, t) in enumerate(t_sobol[1:m])
@@ -567,7 +569,8 @@ end
             base = nextprime(s))
         pass[2, s] = istmsnet(randomize(net, OwenScramble(base = nextprime(s), pad = m));
             λ, t, m, s, base = nextprime(s))
-        pass[3, s] = istmsnet(randomize(net,
+        pass[3, s] = istmsnet(
+            randomize(net,
                 MatousekScramble(base = nextprime(s), pad = m));
             λ, t, m, s, base = nextprime(s))
         pass[4, s] = istmsnet(randomize(net, DigitalShift(base = nextprime(s), pad = m));
